package com.ruoyi.tcZz.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.tcZz.domain.TcWljgtj;
import com.ruoyi.tcZz.domain.TcYqxxlnum;
import com.ruoyi.tcZz.domain.TcYqxxltj;
import com.ruoyi.tcZz.service.ITcYqxxltjService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 舆情信息量统计明細Controller
 *
 * @author ruoyi
 * @date 2023-10-12
 */
@RestController
@Api(tags = "舆情信息量统计明細")
@RequestMapping("/tcZz/netWorkYq/yqxxltj")
public class TcYqxxltjController extends BaseController {
    @Autowired
    private ITcYqxxltjService tcYqxxltjService;

    /**
     * 查询舆情信息量统计明細列表
     */
    @ApiOperation(value = "查询舆情信息量统计明細列表",response = TcYqxxltj.class )
    @GetMapping("/list")
    public TableDataInfo list(TcYqxxltj tcYqxxltj) {
        startPage();
        List<TcYqxxltj> list = tcYqxxltjService.selectTcYqxxltjList(tcYqxxltj);
        return getDataTable(list);
    }

    /**
     * 导出舆情信息量统计明細列表
     */
    @ApiOperation(value = "导出舆情信息量统计明細列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcYqxxltj tcYqxxltj) {
        List<TcYqxxltj> list = tcYqxxltjService.selectTcYqxxltjList(tcYqxxltj);
        ExcelUtil<TcYqxxltj> util = new ExcelUtil<TcYqxxltj>(TcYqxxltj.class);
        util.exportExcel(response, list, "舆情信息量统计明細数据");
    }

    /**
     * 获取舆情信息量统计明細详细信息
     */
    @ApiOperation(value = "获取舆情信息量统计明細详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(tcYqxxltjService.selectTcYqxxltjById(id));
    }

    /**
     * 新增舆情信息量统计明細
     */
    @ApiOperation(value = "新增舆情信息量统计明細")
    @PostMapping
    public AjaxResult add(@RequestBody TcYqxxltj tcYqxxltj) {
        return toAjax(tcYqxxltjService.insertTcYqxxltj(tcYqxxltj));
    }

    /**
     * 修改舆情信息量统计明細
     */
    @ApiOperation(value = "修改舆情信息量统计明細")
    @PutMapping
    public AjaxResult edit(@RequestBody TcYqxxltj tcYqxxltj) {
        return toAjax(tcYqxxltjService.updateTcYqxxltj(tcYqxxltj));
    }

    /**
     * 删除舆情信息量统计明細
     */
    @ApiOperation(value = "删除舆情信息量统计明細")
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(tcYqxxltjService.deleteTcYqxxltjByIds(ids));
    }

    /**
     * 查询舆情信息量统计明細列表
     */
    @ApiOperation(value = "查询舆情信息量统计明細列表")
    @GetMapping("/ListNoToken")
    public TableDataInfo ListNoToken(TcYqxxltj tcYqxxltj) {
        startPage();
        List<TcYqxxltj> list = tcYqxxltjService.selectTcYqxxltjList(tcYqxxltj);
        return getDataTable(list);
    }

    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcYqxxltj> util = new ExcelUtil<TcYqxxltj>(TcYqxxltj.class);
        List<TcYqxxltj> YqxxltjList = util.importExcel(file.getInputStream());
        tcYqxxltjService.importUser(YqxxltjList);
        return AjaxResult.success();
    }
    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus,@RequestParam("ids") List<String> ids) {
        tcYqxxltjService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcYqxxltj> util = new ExcelUtil<TcYqxxltj>(TcYqxxltj.class);
        util.importTemplateExcel(response, " 舆情信息量统计明細列表");
    }
}
